@@ -1,9 +1,10 @@
 from adobject import *
 
 class ADComputer(ADObject):
-    """"""
+    """Python class representing a computer object in Active Directory."""
     @classmethod
     def create(cls, name, container_object, enable=True, optional_attributes={}):
+        """Creates and returns a new computer object."""
         assert type(name) == str
         assert container_object.__class__.__name__ == 'ADContainer'
         return container_object.create_computer(name=name,enable=enable,optional_attributes=optional_attributes)
