@@ -391,7 +391,7 @@ class ADObject(ADBase):
         # kudos to http://docs.activestate.com/activepython/2.6/pywin32/html/com/help/active_directory.html
         return pyadutils.convert_datetime(self.get_attribute('pwdLastSet', False))
 
-    def get_uSNChanged(self)
+    def get_uSNChanged(self):
         """Returns uSNChanged as a single integer from the current domain controller"""
         return pyadutils.convert_bigint(self.get_attribute('uSNChanged', False)) 
         
